@@ -1,10 +1,10 @@
-from platonic.queue.types import ValueType, InternalType
-from platonic.queue.input import InputQueue
-from platonic.queue.output import OutputQueue
-from platonic.queue.message import Message
 from platonic.queue.errors import (
+    MessageDoesNotExist,
     MessageReceiveTimeout,
     MessageTooLarge,
-    MessageDoesNotExist,
     QueueDoesNotExist,
 )
+from platonic.queue.input import InputQueue
+from platonic.queue.message import Message
+from platonic.queue.output import OutputQueue
+from platonic.queue.types import InternalType, ValueType
